@@ -116,10 +116,10 @@ class BeaconAPI(object):
 
             # BEACON_KEY & BEACON_HOST specified?
             elif 'HERMES2_HOME' in os.environ or os.path.isdir("/home/jaminb/v2"):
-                os.environ['HERMES2_HOME'] = os.environ.get('HERMES2_HOME', '/home/jaminb/v2')
+                home = os.environ['HERMES2_HOME'] = os.environ.get('HERMES2_HOME', '/home/jaminb/v2')
                 self._debug("+ HERMES2_HOME set, trying to call v2conf")
                 try:
-                    ekey, self.host = map(str.strip, os.popen("v2conf localapi localurl").readlines())
+                    ekey, self.host = map(str.strip, os.popen("%s/scripts/v2conf.py localapi localurl" % home).readlines())
                 except ValueError:
                     raise BeaconAPIException(500, "Could not call v2conf to determine local API key")
                 self._debug('+ v2conf response: %r / %r' % (ekey, self.host))
