@@ -90,7 +90,7 @@ def login(api, args):
             print "Sorry, that username/password was not correct."
             return
         try:
-            expires = int(response.cookies['HERMES_FKEY'].split('-')[0]) - time.time()
+            expires = int(response.cookies['HERMES_FKEY'].split('-')[1])
             key = 'session %s %s' % (response.cookies['HERMES_FKEY'], response.cookies['BEACON_LOGIN'])
         except KeyError:
             print "Could not login to %s. Are you sure this is a current Beacon server?" % host
